@@ -491,8 +491,11 @@ class RawImageCreator(BaseImageCreator):
 
     def _write_image_xml(self):
         imgarch = "i686"
-        if self.target_arch and self.target_arch.startswith("arm"):
-            imgarch = "arm"
+        if self.target_arch:
+            if self.target_arch.startswith("arm"):
+                imgarch = "arm"
+            elif self.target_arch == "riscv64":
+                imgarch = "riscv64"
         xml = "<image>\n"
 
         name_attributes = ""
